const Chance = require('chance')
const { user, handlingEditor, answerHE } = require('./userData')
const {
  fragment,
  fragment1,
  reviewCompletedFragment,
  noInvitesFragment,
} = require('./fragments')
const {
  standardCollID,
  collectionReviewCompletedID,
  collectionNoInvitesID,
  twoVersionsCollectionId,
} = require('./collectionIDs')

const chance = new Chance()
const collections = {
  collection: {
    id: standardCollID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: false,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: answerHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
  collection1: {
    id: standardCollID,
    delete: jest.fn(),
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: false,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: answerHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    customId: '1234568',
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'reviewCompleted',
  },
  collection2: {
    id: collectionNoInvitesID,
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment1.id, noInvitesFragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection2),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: false,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: answerHE.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    customId: chance.natural({ min: 999999, max: 9999999 }),
    technicalChecks: {
      token: chance.guid(),
    },
    status: 'pendingApproval',
  },
  collectionReviewCompleted: {
    id: collectionReviewCompletedID,
    delete: jest.fn(),
    type: 'collection',
    owners: [user.id],
    status: 'reviewCompleted',
    created: chance.timestamp(),
    customId: '0000001',
    fragments: [reviewCompletedFragment.id],
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        type: 'invitation',
        userId: handlingEditor.id,
        hasAnswer: true,
        invitedOn: chance.timestamp(),
        isAccepted: true,
        respondedOn: chance.timestamp(),
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      name: handlingEditor.name,
      email: handlingEditor.email,
      hasAnswer: true,
      invitedOn: chance.timestamp(),
      isAccepted: true,
      respondedOn: chance.timestamp(),
    },
    technicalChecks: {},
  },
  twoVersionsCollection: {
    id: twoVersionsCollectionId,
    title: chance.sentence(),
    type: 'collection',
    fragments: [fragment.id, reviewCompletedFragment.id],
    owners: [user.id],
    save: jest.fn(() => collections.collection),
    invitations: [
      {
        id: chance.guid(),
        role: 'handlingEditor',
        hasAnswer: true,
        isAccepted: false,
        userId: handlingEditor.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
      },
    ],
    handlingEditor: {
      id: handlingEditor.id,
      hasAnswer: false,
      isAccepted: false,
      email: handlingEditor.email,
      invitedOn: chance.timestamp(),
      respondedOn: null,
      name: `${handlingEditor.firstName} ${handlingEditor.lastName}`,
    },
    status: 'revisionRequested',
    customId: chance.natural({ min: 999999, max: 9999999 }),
  },
}

module.exports = collections
